; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


; These 11 Single Button and Hold Dir commands must be placed here at the top
; of the CMD, above all other commands, and in the standard order shown here,
; in order for the "Compatibly Partnered" version (9742) of the helper AI
; activation method to work with different partners in simul team mode.
; (When the partner is not compatible, then it's best to just use the regular
; version (9741) and rely on the XOR method for backup in case a human
; partner's input turns off the CPU partner's AI.)
; (Now, even if you do not intend to give your character any custom AI, it
; would still be nice if you would place the commands at the top of your CMD,
; for the sake of other characters which do use this AI activation method.
; And then, define Anim 9741 in your AIR file to indicate to other characters
; that your character is compatible.
; It may slightly increase the chances of faulty AI activation if the user is
; using characters with a poor implementation of the old humanly-impossible
; commands AI activation method when fighting against your character, but
; other than that, there's really no particular reason not to.  And you can
; change the names of the commands if you want.  For compatibility, all that
; really matters is the "command" and "time" parameters.)
;
; Another important point to make, is that if you want to add additional
; definitions for any of these basic command names, then there are limits on
; what kind of parameters you can use, in order to ensure the reliability of
; the helper method.  That is, if you redefine any of these first 11 commands,
; then you must follow these rules when doing so:
; - Don't use any command string that includes any tildes. (e.g. no "~x",
;   no "~30D")
; - In the command string, don't include any direction that isn't preceeded by
;   a slash. (e.g. no "F", no "$D")
; - Don't put any non-slashed buttons in a command string overloading one of
;   the Hold Dir command names.
; - Using a command string that includes any commas (e.g. no "a,b"), and/or
;   setting the time parameter to greater than 1, may be safe, but I wouldn't
;   risk it.
; An example of what is permissible, is redefining the "z" button like so:
;	[Command]
;	name = "z"
;	command = y+b
;	time = 1
; Other than that particular common type of redefinition, it's probably best
; to simply avoid adding definitions for these 11 command names altogether.
; And remember, this paragraph just has to do with the helper method.  You'll
; still need to make changes to the XOR code, no matter what type of overloading
; you use with the commands used by it.
;
;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |----------------------------------------------------------
; Please define Anim 74140108 in your AIR file if AND ONLY IF you place these
; 7 Hold Button commands immediately after the 11 Single Button and Hold Dir
; commands at the very top of your CMD list, as demonstrated here.
; In this version of the AI code, these commands are only used by the XOR
; method, and thus are optional.  But there remains a possibility that a
; future version of the helper method might be helped by having these
; commands placed here, and Anim 74140108 would then be used to indicate
; that a partner character has a compatible CMD.

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holdstart"
command = /s
time = 1

;-| CPU |--------------------------------------------------------------
; Note that if you make any changes to the basic one-button or recovery
; commands, you'll need to make the same changes to their matching commands here
; and/or in the XOR VarSet controller.  That includes things like, for example:
;  * changing the recovery command to use a different combination of buttons.
;  * renaming the b button command as "d", or the start button command as "s".
;  * switching the button names around, e.g. so button y triggers "a" and button a triggers "y".
;  * having more than one way to trigger the same command name.
; If you understand how the XOR method works, the proper changes should be obvious.
; If you don't understand it, then simply disable the lines in the XOR VarSet
; controller that correspond to the commands you've altered.

[Command]
name = "a2"
command = a
time = 1

[Command]
name = "b2"
command = b
time = 1

[Command]
name = "c2"
command = c
time = 1

[Command]
name = "x2"
command = x
time = 1

[Command]
name = "y2"
command = y
time = 1

[Command]
name = "z2"
command = z
time = 1

[Command]
name = "start2"
command = s
time = 1

[Command]
name = "holdfwd2"
command = /$F
time = 1

[Command]
name = "holdback2"
command = /$B
time = 1

[Command]
name = "holdup2"
command = /$U
time = 1

[Command]
name = "holddown2"
command = /$D
time = 1

[Command]
name = "holda2"
command = /a
time = 1

[Command]
name = "holdb2"
command = /b
time = 1

[Command]
name = "holdc2"
command = /c
time = 1

[Command]
name = "holdx2"
command = /x
time = 1

[Command]
name = "holdy2"
command = /y
time = 1

[Command]
name = "holdz2"
command = /z
time = 1

[Command]
name = "holdstart2"
command = /s
time = 1

[Command]
name = "recovery2"
command = x+y
time = 1

; Here add matching commands for any moves that must never be used randomly
; by the computer, such as suicide moves and super moves, and add the pairs
; to the XOR VarSet controller in State -3.

; If you're desperate to make sure that the AI always gets turned on as soon
; as possible, you can add more equivalents for your own commands here too,
; and add to the XOR VarSet controller's triggers accordingly.  You should
; use button-only commands before using any commands with directional
; components, as the latter apparently doesn't work in Linux Mugen 2002.04.14.

; And of course, if you've run out of unique command labels (Mugen allows
; 128), you can remove as many of these as you want.  You'll of course need
; to modify the XOR VarSet controller's triggers accordingly, but Mugen
; will let you know if you forget to do so. :)


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "HujKurwaDupaCipa"
command = ~D, DF, F, D, DF, F, x
time = 20

[Command]
name = "HujKurwaDupaCipa"
command = ~D, DF, F, D, DF, F, y
time = 20

[Command]
name = "HujKurwaDupaCipa"
command = ~D, DF, F, D, DF, F, z
time = 20

[Command]
name = "WypierDalac"
command = ~D, DB, B, D, DB, B, x;~F, D, DF, F, D, DF, x
time = 20

[Command]
name = "WypierDalac"
command = ~D, DB, B, D, DB, B, y;~F, D, DF, F, D, DF, y
time = 20

[Command]
name = "WypierDalac"
command = ~D, DB, B, D, DB, B, z;~F, D, DF, F, D, DF, y
time = 20

[Command]
name = "PC"
command = ~50$B, F, B, F, a
time = 25

[Command]
name = "PC"
command = ~50$B, F, B, F, b
time = 25

[Command]
name = "PC"
command = ~50$B, F, B, F, c
time = 25

[Command]
name = "Mad"
command = ~20$B, F, B, F, x
time = 40

[Command]
name = "Mad"
command = ~20$B, F, B, F, y
time = 40

[Command]
name = "Mad"
command = ~20$B, F, B, F, z
time = 40

[Command]
name = "Maluch"
command = ~D, D, z
time = 20

[Command]
name = "Maluch"
command = ~D, D, x+y
time = 20

[Command]
name = "omg"
command = z
time = 1

[Command]
name = "omg"
command = x+y
time = 1

[Command]
name = "wtf"
command = c
time = 1

[Command]
name = "wtf"
command = a+b
time = 1

;-| Special Motions |------------------------------------------------------
[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_xy"
command = ~F, D, DF, x+y

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_xy"
command = ~D, DF, F, x+y

[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "CBF_x"
command = ~20$B, F, x
time = 10

[Command]
name = "CBF_y"
command = ~20$B, F, y
time = 10

[Command]
name = "upper_a"
command = ~F, D, DF, a

[Command]
name = "upper_b"
command = ~F, D, DF, b

[Command]
name = "HCF_a"
command = ~B, DB, D, DF, F, a

[Command]
name = "HCF_b"
command = ~B, DB, D, DF, F, b

[Command]
name = "HCF_a"
command = ~B, D, F, a

[Command]
name = "HCF_b"
command = ~B, D, F, b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "DU"     ;Required (do not remove)
command = ~D, U
time = 10

[Command]
name = "parry"     ;Required (do not remove)
command = F
time = 1

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

; The main purpose of having these next two controllers here at the top of
; StateDef -1 is to make sure the AI helper never changes to a different state,
; but they also improve efficiency by preventing Mugen from wasting time
; processing the entire State -1 for the helper.
[State -1, AI Helper Check]
type = ChangeState
trigger1 = IsHelper(9741)
value = 9741

[State -1, AI Helper Check 2]
type = ChangeState
trigger1 = IsHelper(9742)
value = 9742

; This is generally the best place to put most of your AI directives.  For
; example, this controller would only be executed when the CPU is in control:
;
; [State -1, Haha!]
; type = ChangeState
; trigger1 = var(0) ; (Or use "var(59)>0" if you've chosen not to
;                   ; use the Simplifier variable/controller.)
; trigger1 = ctrl
; trigger1 = (StateType = S)
; trigger1 = (MoveType = I)
; trigger1 = (P2MoveType = H)
; trigger1 = (NumEnemy = 1)
; trigger1 = (Enemy,GetHitVar(HitTime) > 60)
; trigger1 = (PrevStateNo != 195)
; trigger1 = (Random < 99)
; value = 195

; And of course, most human-only command-based ChangeStates also belong
; in State -1.  For example, this move would only be performable by a human:
;
; [State -1, Death Before Dishonor]
; type = ChangeState
; trigger1 = (command = "suicide")
; trigger1 = !var(0) ; (Or use "var(59)<1" if you've chosen not to
;                    ; use the Simplifier variable/controller.)
; trigger1 = ctrl
; trigger1 = (StateType != A)
; trigger1 = (MoveType = I)
; value = {suicide state number}



;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = stateno != 250 ;Except for sweep kick
trigger2 = movecontact
var(1) = 1

; AI START

[State -1, AI]
type = ChangeState
triggerall = Var(57) > 0
triggerall = statetype != A
triggerall = power >= 1000
triggerall = life <= 400
triggerall = roundno != 1
triggerall = !var(51)
trigger1 = ctrl
trigger1 = random < 200
value = 4000

[State -3: ChangeState]
type = ChangeState
triggerall = (Var(57) > 0) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing)
trigger1 = (P2StateType != C) && (P2MoveType = A) && ((p2dist x < 160) || (EnemyNear, NumProj > 0))
value = 130

[State -3: ChangeState]
type = ChangeState
triggerall = (Var(57) > 0) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing)
trigger1 = (P2StateType = C) && (P2MoveType = A) && ((p2dist x < 160) || (EnemyNear, NumProj > 0))
value = 131

;[State -3: ChangeState]
;type = ChangeState
;triggerall = (Var(57) > 0) && (StateType = A) && (Ctrl) && (EnemyNear, Facing != Facing)
;trigger1 = (P2MoveType = A) && ((p2dist x < 160) || (EnemyNear, NumProj > 0))
;value = 132

; First Punch
[State -1, AI]
type = ChangeState
triggerall = Var(57) > 0
triggerall = statetype != A
triggerall = p2stateno = [5100,5119]
trigger1 = random < 40
trigger1 = ctrl
value = ifelse(random<500,1500,1510)

; Overhead attack
[State -1, AI]
type = ChangeState
triggerall = var(57)
triggerall = statetype != A
triggerall = p2statetype != A
triggerall = p2movetype != A
triggerall = p2bodydist x <= 50
triggerall = random < 500
trigger1 = ctrl
trigger1 = p2stateno = [120,169]
trigger1 = p2statetype = C
value = ifelse(random<500,1300,1310)

; GRAB!
[State -1, AI]
type = ChangeState
triggerall = Var(57) > 0
triggerall = statetype != A
triggerall = p2statetype = S || p2statetype = C
triggerall = p2movetype != H
triggerall = p2bodydist x < 8
triggerall = random < 500
trigger1 = ctrl
value = ifelse(random<500,800,830)

; First Punch
[State -1, AI supa]
type = ChangeState
triggerall = p2stateno != [5100,5200]
triggerall = Var(57) > 0
triggerall = statetype != A
triggerall = p2statetype = S
triggerall = (p2movetype != A || EnemyNear, Facing = Facing)
triggerall = p2bodydist x <= 65
triggerall = p2bodydist y >= -14
triggerall = power >= 1000
trigger1 = ctrl
trigger1 = random < 100
trigger2 = random < 210
trigger2 = stateno = [200,499]
trigger2 = stateno != 410
trigger2 = stateno != 430
trigger2 = movehit
value = ifelse(p2bodydist x <= 37,3000,3100) + ifelse(random<200&&power>=2000,40,0) + ifelse(random<80&&power>=3000,40,0)

; First Punch
[State -1, AI]
type = ChangeState
triggerall = p2stateno != [5100,5200]
triggerall = Var(57) > 0
triggerall = statetype != A
triggerall = p2statetype = S
triggerall = (p2movetype != A || EnemyNear, Facing = Facing)
triggerall = p2bodydist x <= 55
triggerall = p2bodydist y >= -20
trigger1 = ctrl
value = ifelse(random<500,200,230)

; Crouch First Punch
[State -1, AI]
type = ChangeState
triggerall = p2stateno != [5100,5200]
triggerall = Var(57) > 0
triggerall = statetype != A
triggerall = p2statetype = C
triggerall = (p2movetype != A || EnemyNear, Facing = Facing)
triggerall = p2bodydist x <= 48
triggerall = p2bodydist y >= -10
triggerall = random < 500
trigger1 = ctrl
value = ifelse(random<500,400,430)

; First Punch
[State -1, AI]
type = ChangeState
triggerall = p2stateno != [5100,5200]
triggerall = Var(57) > 0
triggerall = statetype != A
triggerall = p2statetype = S
triggerall = (p2movetype != A || EnemyNear, Facing = Facing)
triggerall = p2bodydist x <= 72
triggerall = p2bodydist y >= -20
trigger1 = random < 400
trigger1 = ctrl
trigger2 = movecontact
trigger2 = stateno = 200 || stateno = 230
value = ifelse(random<500,210,240)

; Crouch First Punch
[State -1, AI]
type = ChangeState
triggerall = p2stateno != [5100,5200]
triggerall = Var(57) > 0
triggerall = statetype != A
triggerall = p2statetype = C
triggerall = (p2movetype != A || EnemyNear, Facing = Facing)
triggerall = p2bodydist x <= 65
triggerall = p2bodydist y >= -10
trigger1 = random < 400
trigger1 = ctrl
trigger2 = movecontact
trigger2 = stateno = 400 || stateno = 430
value = ifelse(random<500||stateno=430,410,440)

; First Punch
[State -1, AI]
type = ChangeState
triggerall = p2stateno != [5100,5200]
triggerall = Var(57) > 0
triggerall = statetype != A
triggerall = p2statetype = S
triggerall = (p2movetype != A || EnemyNear, Facing = Facing)
triggerall = p2bodydist x <= 100
triggerall = p2bodydist y >= -20
trigger1 = random < 100
trigger1 = ctrl
trigger2 = movecontact
trigger2 = stateno = 210 || stateno = 240
value = ifelse(random<500, ifelse(random<500,1400,1410) ,250)

; First Punch
[State -1, AI]
type = ChangeState
triggerall = p2stateno != [5100,5200]
triggerall = Var(57) > 0
triggerall = statetype != A
triggerall = (p2movetype != A || EnemyNear, Facing = Facing)
triggerall = p2bodydist x <= 70
triggerall = p2bodydist y < -20
trigger1 = random < 210
trigger1 = ctrl
value = ifelse(random<500,1100,1110) + ifelse(random<500,0,300)

; First Punch
[State -1, AI]
type = ChangeState
triggerall = p2stateno != [5100,5200]
triggerall = Var(57) > 0
triggerall = statetype != A
triggerall = (p2movetype != A || EnemyNear, Facing = Facing)
triggerall = p2bodydist x >= 100
triggerall = p2bodydist y >= -20
trigger1 = random < 100
trigger1 = ctrl
trigger2 = movecontact
trigger2 = stateno = 210 || stateno = 240
value = ifelse(random<500,1300,1000)

; PROTTON CANNON POWA!!!
[State -1, AI]
type = ChangeState
triggerall = p2stateno != [5100,5200]
triggerall = Var(57) > 0
triggerall = statetype != A
triggerall = (p2movetype != A || EnemyNear, Facing = Facing)
triggerall = p2bodydist x >= 120
triggerall = power >= 3000
trigger1 = ctrl
trigger1 = random < 400
value = 3900

; Some Mobility
[State -1, AI rt]
type = ChangeState
triggerall = Var(57) > 0
triggerall = statetype != A
triggerall = movetype != A
triggerall = (p2movetype != A || EnemyNear, Facing = Facing)
triggerall = p2bodydist x >= 62
triggerall = random = [800,950]
triggerall = stateno != 100
triggerall = p2stateno != [800,899]
trigger1 = ctrl
value = ifelse(random<500,100, ifelse(power>=1000&&random<500, ifelse( power>=2000&&random<300, ifelse(power>=3000&random<100, 3260, 3240) ,  3200 ) ,1200)  )

; Some Mobility
[State -1, AI]
type = ChangeState
triggerall = Var(57) > 0
triggerall = statetype != A
triggerall = movetype != A
triggerall = (p2movetype != A || EnemyNear, Facing = Facing)
triggerall = p2bodydist x >= 62
triggerall = random = [100,400]
triggerall = stateno != 100
trigger1 = ctrl
value = 100

[State -1, AI]
type = ChangeState
triggerall = Var(57) > 0
triggerall = p2movetype = A
triggerall = random = [150,250]
trigger1 = stateno = 106
trigger1 = animtime = 0
value = 40

; AI END

;---------------------------------------------------------------------------
;Fiat 126p ;)
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = 4000
triggerall = command = "Maluch"
triggerall = life <= 400
triggerall = !var(51)
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = 1000
trigger2 = movecontact

;---------------------------------------------------------------------------
;PROTTON CANNON POWA!!!
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = 3900
triggerall = command = "PC"
triggerall = power >= 3000
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = 1000
trigger2 = movecontact

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = 3080
triggerall = command = "WypierDalac"
triggerall = power >= 3000
triggerall = command = "omg"
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = 1000
trigger2 = movecontact
trigger3 = stateno = 3100
trigger3 = movecontact

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = ifelse(command="y"&&power>=2000,3040,3000)
triggerall = command = "WypierDalac"
triggerall = power >= 1000
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = 1000
trigger2 = movecontact
trigger3 = stateno = 3100
trigger3 = movecontact

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = 3180
triggerall = command = "HujKurwaDupaCipa"
triggerall = command = "omg"
triggerall = power >= 3000
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = 1000
trigger2 = movecontact

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = 3140
triggerall = command = "HujKurwaDupaCipa"
triggerall = command = "y"
triggerall = power >= 2000
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = 1000
trigger2 = movecontact

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = 3100
triggerall = command = "HujKurwaDupaCipa"
triggerall = power >= 1000
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = 1000
trigger2 = movecontact

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = 3260
triggerall = command = "Mad"
triggerall = command = "omg"
triggerall = power >= 3000
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = 1000
trigger2 = movecontact
trigger3 = stateno = 3100
trigger3 = movecontact

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = 3240
triggerall = command = "Mad"
triggerall = command = "y"
triggerall = power >= 2000
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = 1000
trigger2 = movecontact
trigger3 = stateno = 3100
trigger3 = movecontact

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = 3200
triggerall = command = "Mad"
triggerall = power >= 1000
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = 1000
trigger2 = movecontact
trigger3 = stateno = 3100
trigger3 = movecontact

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = ifelse(command="x",1100,1110)
triggerall = command = "upper_x" || command = "upper_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = ifelse(command="a",1300,1310)
triggerall = command = "upper_a" || command = "upper_b"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = 1600
triggerall = command = "HCF_a" || command = "HCF_b"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = ifelse(command="x",1500,1510)
triggerall = command = "QCB_x" || command = "QCB_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = ifelse(command="a",1400,1410)
triggerall = command = "QCB_a" || command = "QCB_b"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = 1000
triggerall = command = "QCF_x" || command = "QCF_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = 1200
triggerall = command = "CBF_x" || command = "CBF_y"
trigger1 = var(1) ;Use combo condition (above)

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Super Jump
;_bV
[State -1, SuperJump]
type = ChangeState
value = 41
trigger1 = command = "DU"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Kung Fu Throw
;
[State -1, Kung Fu Throw]
type = ChangeState
value = 830
triggerall = command = "b"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;---------------------------------------------------------------------------
;Kung Fu Throw
;
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = command = "y"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;===========================================================================
;---------------------------------------------------------------------------
;Stand Burst
[State -1, Stand Burst]
type = ChangeState
value = ifelse(movetype!=H,900,902)
triggerall = command = "omg"
triggerall = !var(50)
triggerall = numenemy
triggerall = alive
;triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,699] ; stateno = [200,499]
trigger2 = movecontact
trigger3 = stateno = [120,169]
trigger4 = movetype = H
trigger4 = statetype != L
trigger4 = !(enemynear,hitdefattr = SC, HA, HP, HT)

;---------------------------------------------------------------------------
; Back Evasion
[State -1, Stand Strong Punch]
type = ChangeState
value = 705
triggerall = command = "wtf"
triggerall = command = "holdback"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [120,169]
trigger2 = power >= 500
trigger2 = statetype != A

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact

[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 230 || stateno = 400
trigger2 = movecontact

[State -1, Stand Light Punch]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 400
trigger2 = movecontact

[State -1, Stand Strong Punch]
type = ChangeState
value = 250
triggerall = command = "b"
triggerall = command = "holdfwd"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 230 || stateno = 210 || stateno = 240
trigger2 = movecontact

[State -1, Stand Strong Punch]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 230
trigger2 = movecontact

;---------------------------------------------------------------------------
;Respect
;
[State -1, Respect]
type = null;ChangeState
value = 186
triggerall = power >= 3000
triggerall = command = "holdback"
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Respect
;
[State -1, Respect]
type = ChangeState
value = 196
triggerall = command = "holdfwd"
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Evasion
[State -1, Stand Strong Punch]
type = ChangeState
value = 700
triggerall = command = "wtf"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [120,169]
trigger2 = power >= 500
trigger2 = statetype != A


;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 400 || stateno = 200
trigger2 = movecontact

[State -1, Stand Light Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 400 || stateno = 200 || stateno = 430 || stateno = 230 || stateno = 210
trigger2 = movecontact

[State -1, Stand Light Punch]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = movecontact

[State -1, Stand Light Punch]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = movecontact
trigger3 = stateno = 430
trigger3 = movecontact

[State -1, Air Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = movecontact

[State -1, Air Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630
trigger2 = movecontact

[State -1, Air Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = movecontact

[State -1, Air Stomp]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630
trigger2 = movecontact


